@@ -1,9 +1,9 @@
 package App::VivaldiUtils;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-04-11'; # DATE
+our $DATE = '2020-04-19'; # DATE
 our $DIST = 'App-VivaldiUtils'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -70,6 +70,26 @@ sub vivaldi_is_paused {
     App::BrowserUtils::_do_browser('is_paused', 'vivaldi', @_);
 }
 
+$SPEC{vivaldi_is_running} = {
+    v => 1.1,
+    summary => "Check whether Vivaldi is running",
+    description => <<'_',
+
+Vivaldi is defined as running if there are some Vivaldi processes that are *not*
+in 'stop' state. In other words, if Vivaldi has been started but is currently
+paused, we do not say that it's running. If you want to check if Vivaldi process
+exists, you can use `ps_vivaldi`.
+
+_
+    args => {
+        %App::BrowserUtils::args_common,
+        %App::BrowserUtils::argopt_quiet,
+    },
+};
+sub vivaldi_is_running {
+    App::BrowserUtils::_do_browser('is_running', 'vivaldi', @_);
+}
+
 $SPEC{terminate_vivaldi} = {
     v => 1.1,
     summary => "Terminate  (kill -KILL) Vivaldi",
@@ -96,7 +116,7 @@ App::VivaldiUtils - Utilities related to the Vivaldi browser
 
 =head1 VERSION
 
-This document describes version 0.004 of App::VivaldiUtils (from Perl distribution App-VivaldiUtils), released on 2020-04-11.
+This document describes version 0.005 of App::VivaldiUtils (from Perl distribution App-VivaldiUtils), released on 2020-04-19.
 
 =head1 SYNOPSIS
 
@@ -118,6 +138,8 @@ This distribution includes several utilities related to the Vivaldi browser:
 
 =item * L<vivaldi-is-paused>
 
+=item * L<vivaldi-is-running>
+
 =back
 
 =head1 FUNCTIONS
@@ -290,6 +312,47 @@ Arguments ('*' denotes required arguments):
 Kill browser processes that belong to certain user(s) only.
 
 
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
+=head2 vivaldi_is_running
+
+Usage:
+
+ vivaldi_is_running(%args) -> [status, msg, payload, meta]
+
+Check whether Vivaldi is running.
+
+Vivaldi is defined as running if there are some Vivaldi processes that are I<not>
+in 'stop' state. In other words, if Vivaldi has been started but is currently
+paused, we do not say that it's running. If you want to check if Vivaldi process
+exists, you can use C<ps_vivaldi>.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<quiet> => I<true>
+
+=item * B<users> => I<array[unix::local_uid]>
+
+Kill browser processes that belong to certain user(s) only.
+
+
 =back
 
 Returns an enveloped result (an array).
@@ -324,7 +387,7 @@ feature.
 Some other CLI utilities related to Vivaldi: L<dump-vivaldi-history> (from
 L<App::DumpVivaldiHistory>).
 
-L<App::ChromeUtils>
+L<App::OperaUtils>
 
 L<App::FirefoxUtils>
 
